@@ -577,6 +577,13 @@ osinfo_db_guess_os_from_media_internal(OsinfoDb *db,
             const gchar *os_application = osinfo_media_get_application_id(os_media);
             gint64 os_vol_size = osinfo_media_get_volume_size(os_media);
 
+            if (os_volume == NULL &&
+                os_system == NULL &&
+                os_publisher == NULL &&
+                os_application == NULL &&
+                os_vol_size <= 0)
+                continue;
+
             if (os_vol_size <= 0)
                 os_vol_size = media_vol_size;
 
@@ -758,10 +765,18 @@ OsinfoOs *osinfo_db_guess_os_from_tree(OsinfoDb *db,
 
         for (tree_iter = trees; tree_iter; tree_iter = tree_iter->next) {
             OsinfoTree *os_tree = OSINFO_TREE(tree_iter->data);
-            const gchar *os_family = osinfo_tree_get_treeinfo_family(os_tree);
-            const gchar *os_variant = osinfo_tree_get_treeinfo_variant(os_tree);
-            const gchar *os_version = osinfo_tree_get_treeinfo_version(os_tree);
-            const gchar *os_arch = osinfo_tree_get_treeinfo_arch(os_tree);
+            const gchar *os_family;
+            const gchar *os_variant;
+            const gchar *os_version;
+            const gchar *os_arch;
+
+            if (!osinfo_tree_has_treeinfo(os_tree))
+                continue;
+
+            os_family = osinfo_tree_get_treeinfo_family(os_tree);
+            os_variant = osinfo_tree_get_treeinfo_variant(os_tree);
+            os_version = osinfo_tree_get_treeinfo_version(os_tree);
+            os_arch = osinfo_tree_get_treeinfo_arch(os_tree);
 
             if (match_regex(os_family, tree_family) &&
                 match_regex(os_variant, tree_variant) &&
