@@ -29,9 +29,13 @@
 #include <osinfo/osinfo_medialist.h>
 #include <osinfo/osinfo_media.h>
 #include <osinfo/osinfo_treelist.h>
+#include <osinfo/osinfo_os_variant.h>
+#include <osinfo/osinfo_os_variantlist.h>
 #include <osinfo/osinfo_tree.h>
 #include <osinfo/osinfo_resources.h>
 #include <osinfo/osinfo_resourceslist.h>
+#include <osinfo/osinfo_image.h>
+#include <osinfo/osinfo_imagelist.h>
 
 #ifndef __OSINFO_OS_H__
 #define __OSINFO_OS_H__
@@ -55,8 +59,9 @@ typedef struct _OsinfoOsClass   OsinfoOsClass;
 
 typedef struct _OsinfoOsPrivate OsinfoOsPrivate;
 
-#define OSINFO_OS_PROP_FAMILY    "family"
-#define OSINFO_OS_PROP_DISTRO    "distro"
+#define OSINFO_OS_PROP_FAMILY                 "family"
+#define OSINFO_OS_PROP_DISTRO                 "distro"
+#define OSINFO_OS_PROP_RELEASE_STATUS         "release-status"
 
 /* object */
 struct _OsinfoOs
@@ -78,6 +83,21 @@ struct _OsinfoOsClass
     /* class members */
 };
 
+/**
+ * OsinfoReleaseStatus:
+ * @OSINFO_RELEASE_STATUS_RELEASED: A released OS.
+ * @OSINFO_RELEASE_STATUS_SNAPSHOT: A continuous integration snapshot and not
+ * an actual released product yet. For example, gnome-continuous images for
+ * development snapshots of GNOME and nightly build ISOs of Fedora etc.
+ * @OSINFO_RELEASE_STATUS_PRERELEASE: A pre-release. For example, alpha and
+ * beta pre-releases of Fedora etc.
+ */
+typedef enum {
+    OSINFO_RELEASE_STATUS_RELEASED,
+    OSINFO_RELEASE_STATUS_SNAPSHOT,
+    OSINFO_RELEASE_STATUS_PRERELEASE
+} OsinfoReleaseStatus;
+
 GType osinfo_os_get_type(void);
 
 OsinfoOs *osinfo_os_new(const gchar *id);
@@ -89,18 +109,28 @@ OsinfoDeviceList *osinfo_os_get_devices_by_property(OsinfoOs *os,
                                                     const char *value,
                                                     gboolean inherited);
 OsinfoDeviceLinkList *osinfo_os_get_device_links(OsinfoOs *os, OsinfoFilter *filter);
+OsinfoDeviceLinkList *osinfo_os_get_all_device_links(OsinfoOs *os, OsinfoFilter *filter);
 
 OsinfoDeviceLink *osinfo_os_add_device(OsinfoOs *os, OsinfoDevice *dev);
 const gchar *osinfo_os_get_family(OsinfoOs *os);
 const gchar *osinfo_os_get_distro(OsinfoOs *os);
+int osinfo_os_get_release_status(OsinfoOs *os);
 OsinfoMediaList *osinfo_os_get_media_list(OsinfoOs *os);
 void osinfo_os_add_media(OsinfoOs *os, OsinfoMedia *media);
 OsinfoTreeList *osinfo_os_get_tree_list(OsinfoOs *os);
 void osinfo_os_add_tree(OsinfoOs *os, OsinfoTree *tree);
+OsinfoImageList *osinfo_os_get_image_list(OsinfoOs *os);
+void osinfo_os_add_image(OsinfoOs *os, OsinfoImage *image);
+OsinfoOsVariantList *osinfo_os_get_variant_list(OsinfoOs *os);
+void osinfo_os_add_variant(OsinfoOs *os, OsinfoOsVariant *variant);
+OsinfoResourcesList *osinfo_os_get_network_install_resources(OsinfoOs *os);
 OsinfoResourcesList *osinfo_os_get_minimum_resources(OsinfoOs *os);
 OsinfoResourcesList *osinfo_os_get_recommended_resources(OsinfoOs *os);
+OsinfoResourcesList *osinfo_os_get_maximum_resources(OsinfoOs *os);
+void osinfo_os_add_network_install_resources(OsinfoOs *os, OsinfoResources *resources);
 void osinfo_os_add_minimum_resources(OsinfoOs *os, OsinfoResources *resources);
 void osinfo_os_add_recommended_resources(OsinfoOs *os, OsinfoResources *resources);
+void osinfo_os_add_maximum_resources(OsinfoOs *os, OsinfoResources *resources);
 
 OsinfoInstallScript *osinfo_os_find_install_script(OsinfoOs *os, const gchar *profile);
 OsinfoInstallScriptList *osinfo_os_get_install_script_list(OsinfoOs *os);
