@@ -62,6 +62,9 @@ osinfo_productfilter_finalize(GObject *object)
 
     g_hash_table_unref(productfilter->priv->productConstraints);
 
+    if (productfilter->priv->supportDate)
+        g_date_free(productfilter->priv->supportDate);
+
     /* Chain up to the parent class */
     G_OBJECT_CLASS(osinfo_productfilter_parent_class)->finalize(object);
 }
@@ -94,17 +97,10 @@ OsinfoProductFilter *osinfo_productfilter_new(void)
 }
 
 
-static void
-osinfo_productfilter_product_constraint_free(gpointer value, gpointer opaque G_GNUC_UNUSED)
-{
-    g_object_unref(value);
-}
-
 static void
 osinfo_productfilter_product_constraints_free(gpointer relshps)
 {
-    g_list_foreach(relshps, osinfo_productfilter_product_constraint_free, NULL);
-    g_list_free(relshps);
+    g_list_free_full(relshps, g_object_unref);
 }
 
 static void
@@ -276,16 +272,26 @@ static gboolean osinfo_productfilter_matches_default(OsinfoFilter *filter, Osinf
 
     if (productfilter->priv->supportDate) {
         GDate *when = productfilter->priv->supportDate;
-        GDate *release = osinfo_product_get_release_date(OSINFO_PRODUCT(entity));
-        GDate *eol = osinfo_product_get_eol_date(OSINFO_PRODUCT(entity));
+        GDate *release;
+        GDate *eol;
 
-        if (release &&
-            (g_date_compare(release, when) > 0))
-            return FALSE;
+        release = osinfo_product_get_release_date(OSINFO_PRODUCT(entity));
+        if (release != NULL) {
+            gboolean newer;
+            newer = (g_date_compare(release, when) > 0);
+            g_date_free(release);
+            if (newer)
+                return FALSE;
+        }
 
-        if (eol &&
-            (g_date_compare(eol, when) < 0))
-            return FALSE;
+        eol = osinfo_product_get_eol_date(OSINFO_PRODUCT(entity));
+        if (eol != NULL) {
+            gboolean older;
+            older = (g_date_compare(eol, when) < 0);
+            g_date_free(eol);
+            if (older)
+                return FALSE;
+        }
     }
 
     return args.matched;
