@@ -110,6 +110,7 @@ enum {
     PROP_KERNEL_PATH,
     PROP_INITRD_PATH,
     PROP_BOOT_ISO_PATH,
+    PROP_HAS_TREEINFO,
 };
 
 static void
@@ -166,6 +167,11 @@ osinfo_tree_get_property(GObject *object,
                            osinfo_tree_get_boot_iso_path(tree));
         break;
 
+    case PROP_HAS_TREEINFO:
+        g_value_set_boolean(value,
+                            osinfo_tree_has_treeinfo(tree));
+        break;
+
     default:
         /* We don't have any other property... */
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
@@ -237,6 +243,12 @@ osinfo_tree_set_property(GObject      *object,
                                 g_value_get_string(value));
         break;
 
+    case PROP_HAS_TREEINFO:
+        osinfo_entity_set_param_boolean(OSINFO_ENTITY(tree),
+                                        OSINFO_TREE_PROP_HAS_TREEINFO,
+                                        g_value_get_boolean(value));
+        break;
+
     default:
         /* We don't have any other property... */
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
@@ -380,6 +392,18 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_BOOT_ISO_PATH, pspec);
 
+    /**
+     * OsinfoTree:has-treeinfo
+     *
+     * Whether the tree has treeinfo or not
+     */
+    pspec = g_param_spec_boolean("has-treeinfo",
+                                 "HasTreeinfo",
+                                 _("Whether the tree has treeinfo"),
+                                 TRUE /* default value */,
+                                 G_PARAM_READWRITE |
+                                 G_PARAM_STATIC_STRINGS);
+    g_object_class_install_property(g_klass, PROP_HAS_TREEINFO, pspec);
 }
 
 static void
@@ -437,7 +461,7 @@ OsinfoTree *osinfo_tree_create_from_location(const gchar *location,
 
     data = g_slice_new0(CreateFromLocationData);
     data->main_loop = g_main_loop_new(g_main_context_get_thread_default(),
-                                      TRUE);
+                                      FALSE);
 
     osinfo_tree_create_from_location_async(location,
                                            G_PRIORITY_DEFAULT,
@@ -446,8 +470,7 @@ OsinfoTree *osinfo_tree_create_from_location(const gchar *location,
                                            data);
 
     /* Loop till we get a reply (or time out) */
-    if (g_main_loop_is_running(data->main_loop))
-        g_main_loop_run(data->main_loop);
+    g_main_loop_run(data->main_loop);
 
     ret = osinfo_tree_create_from_location_finish(data->res, error);
     create_from_location_data_free(data);
@@ -472,6 +495,13 @@ static gboolean is_str_empty(const gchar *str) {
     return ret;
 }
 
+static gboolean is_unknown_group_or_key_error(const GError *error)
+{
+    return (g_error_matches(error, G_KEY_FILE_ERROR,
+                            G_KEY_FILE_ERROR_KEY_NOT_FOUND) ||
+            g_error_matches(error, G_KEY_FILE_ERROR,
+                            G_KEY_FILE_ERROR_GROUP_NOT_FOUND));
+}
 
 static OsinfoTree *load_keyinfo(const gchar *location,
                                 const gchar *content,
@@ -493,44 +523,51 @@ static OsinfoTree *load_keyinfo(const gchar *location,
                                    G_KEY_FILE_NONE, error))
         goto cleanup;
 
-    if (!(family = g_key_file_get_string(file, "general", "family", error)) &&
-        (*error && (*error)->code != G_KEY_FILE_ERROR_KEY_NOT_FOUND &&
-         (*error)->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
-        goto cleanup;
+    if (!(family = g_key_file_get_string(file, "general", "family", error))) {
+        if (!is_unknown_group_or_key_error(*error))
+            goto cleanup;
+        g_clear_error(error);
+    }
 
-    if (!(variant = g_key_file_get_string(file, "general", "variant", error)) &&
-        (*error && (*error)->code != G_KEY_FILE_ERROR_KEY_NOT_FOUND &&
-         (*error)->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
-        goto cleanup;
+    if (!(variant = g_key_file_get_string(file, "general", "variant", error))) {
+        if (!is_unknown_group_or_key_error(*error))
+            goto cleanup;
+        g_clear_error(error);
+    }
 
-    if (!(version = g_key_file_get_string(file, "general", "version", error)) &&
-        (*error && (*error)->code != G_KEY_FILE_ERROR_KEY_NOT_FOUND &&
-         (*error)->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
-        goto cleanup;
+    if (!(version = g_key_file_get_string(file, "general", "version", error))) {
+        if (!is_unknown_group_or_key_error(*error))
+            goto cleanup;
+        g_clear_error(error);
+    }
 
-    if (!(arch = g_key_file_get_string(file, "general", "arch", error)) &&
-        (*error && (*error)->code != G_KEY_FILE_ERROR_KEY_NOT_FOUND &&
-         (*error)->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
-        goto cleanup;
+    if (!(arch = g_key_file_get_string(file, "general", "arch", error))) {
+        if (!is_unknown_group_or_key_error(*error))
+            goto cleanup;
+        g_clear_error(error);
+    }
 
 
     if (arch) {
         group = g_strdup_printf("images-%s", arch);
 
-        if (!(kernel = g_key_file_get_string(file, group, "kernel", error)) &&
-            (*error && (*error)->code != G_KEY_FILE_ERROR_KEY_NOT_FOUND &&
-             (*error)->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
-            goto cleanup;
+        if (!(kernel = g_key_file_get_string(file, group, "kernel", error))) {
+            if (!is_unknown_group_or_key_error(*error))
+                goto cleanup;
+            g_clear_error(error);
+        }
 
-        if (!(initrd = g_key_file_get_string(file, group, "initrd", error)) &&
-            (*error && (*error)->code != G_KEY_FILE_ERROR_KEY_NOT_FOUND &&
-             (*error)->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
-            goto cleanup;
+        if (!(initrd = g_key_file_get_string(file, group, "initrd", error))) {
+            if (!is_unknown_group_or_key_error(*error))
+                goto cleanup;
+            g_clear_error(error);
+        }
 
-        if (!(bootiso = g_key_file_get_string(file, group, "boot.iso", error)) &&
-            (*error && (*error)->code != G_KEY_FILE_ERROR_KEY_NOT_FOUND &&
-             (*error)->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
-            goto cleanup;
+        if (!(bootiso = g_key_file_get_string(file, group, "boot.iso", error))) {
+            if (!is_unknown_group_or_key_error(*error))
+                goto cleanup;
+            g_clear_error(error);
+        }
     }
 
     tree = osinfo_tree_new(location, arch ? arch : "i386");
@@ -835,6 +872,20 @@ const gchar *osinfo_tree_get_initrd_path(OsinfoTree *tree)
                                          OSINFO_TREE_PROP_INITRD);
 }
 
+/**
+ * osinfo_tree_has_treeinfo:
+ * @tree: an #OsinfoTree instance
+ *
+ * Return whether a tree has treeinfo or not.
+ *
+ * Returns: TRUE if the tree has treeinfo. FALSE otherwise.
+ */
+gboolean osinfo_tree_has_treeinfo(OsinfoTree *tree)
+{
+    return osinfo_entity_get_param_value_boolean(OSINFO_ENTITY(tree),
+                                                 OSINFO_TREE_PROP_HAS_TREEINFO);
+}
+
 /*
  * Local variables:
  *  indent-tabs-mode: nil
