@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * with this program. If not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *   Daniel P. Berrange <berrange@redhat.com>
@@ -47,7 +46,16 @@ static void test_tree(OsinfoTreeList *treelist, GError **error, CURL *curl)
         curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &response_code);
 
         g_test_message("res=%d, %s; code=%ld", res, curl_easy_strerror(res), response_code);
-        g_assert_cmpint(res, ==, CURLE_OK);
+
+        if (res == CURLE_OPERATION_TIMEDOUT) {
+            g_printerr("Ignoring network timeout failure for %s\n", url);
+        } else {
+            if (res != CURLE_OK) {
+                g_printerr("Failed URI %s res=%d (%s) code=%ld\n",
+                           url, res, curl_easy_strerror(res), response_code);
+            }
+            g_assert_cmpint(res, ==, CURLE_OK);
+        }
 
         tmp = tmp->next;
     }
@@ -116,6 +124,7 @@ main(int argc, char *argv[])
     int ret;
 
     g_test_init(&argc, &argv, NULL);
+    g_test_set_nonfatal_assertions();
 
     g_test_add_func("/treeuris/uris", test_uris);
 
